@@ -1,11 +1,14 @@
 #include "wifipassworddialog.h"
 #include "ui_wifipassworddialog.h"
 
+#include <QCloseEvent>
+
 WifiPasswordDialog::WifiPasswordDialog(QString ssid, QWidget *parent) :
     QDialog(parent),
     ui(new Ui::WifiPasswordDialog)
 {
     ui->setupUi(this);
+
     ui->wifiLabel->setText(tr("Enter password for %1:").arg(ssid));
     connect(ui->connectButton, &QPushButton::clicked, this, &WifiPasswordDialog::onConnectClicked);
 }
@@ -25,3 +28,8 @@ QString WifiPasswordDialog::getPassword()
 {
     return password;
 }
+
+void WifiPasswordDialog::closeEvent(QCloseEvent *event)
+{
+    event->ignore();
+}
